import arcpy
from arcpy.sa import *
from arcpy import management as DM
arcpy.env.overwriteOutput = True


# Inputs
Growing_Degree_Days = arcpy.GetParameterAsText(0)
Precipitation = arcpy.GetParameterAsText(1)
Evapotranspiration = arcpy.GetParameterAsText(2)

#Temp files
Thermal_Reclass = "%scratchWorkspace%\\th_8"
Aridity_Index = "%scratchWorkspace%\\ai"
Aridity_Reclass = "%scratchWorkspace%\\Reclass_ai1"
rastercalc = "%scratchWorkspace%\\rastercalc"
climate_class = "%scratchWorkspace%\\climate_class"

# Output File
climate_class_output = arcpy.GetParameterAsText(3)

# Process: Reclassify (2)
arcpy.AddMessage("Reclassifying growing degree days")
Thermal_Reclass = Reclassify(Growing_Degree_Days, "VALUE", RemapRange([[0,30,10],[30,3000,20],[3000,15700,30],[15700,30700,40],[30700,59500,50],[59500,92500,60],[92500,115000,70],[115000,10000000,80]]), "DATA")

# Process: Divide
arcpy.AddMessage("Dividing precipitation by evapotranspiration to create aridity index")
Aridity_Index = Divide(Precipitation, Evapotranspiration)

# Process: Reclassify
arcpy.AddMessage("Reclassifying aridity index")
Aridity_Reclass = Reclassify(Aridity_Index, "VALUE", RemapRange([[0,0.050000,1],[0.050000,0.200000,2],[0.200000,0.500000,3],[0.500000,1.250000,4],[1.250000,10000000,5]]), "DATA")

# Process: Raster Calculator
arcpy.AddMessage("Adding thermal reclassification and aridity reclassification")
rastercalc = Thermal_Reclass + Aridity_Reclass

# Process: Reclassify (3)
arcpy.AddMessage("Reclassifying result of thermal and aridity addition for final output")
climate_class = Reclassify(rastercalc, "VALUE", RemapValue([[11,3],[12,3],[13,3],[14,4],[15,5],[21,8],[22,8],[23,8],[24,9],[25,10],[31,12],[32,12],[33,13],[34,14],[35,15],[41,17],[42,17],[43,18],[44,19],[45,20],[51,21],[52,22],[53,23],[54,24],[55,25],[61,26],[62,27],[63,28],[64,29],[65,30],[71,31],[72,32],[73,33],[74,34],[75,35],[81,41],[82,42],[83,43],[84,44],[85,45]]), "DATA")

climate_class.save(climate_class_output)

DM.Delete(Thermal_Reclass)
DM.Delete(Aridity_Index)
DM.Delete(Aridity_Reclass)
DM.Delete(rastercalc)
